@@ -15,30 +15,10 @@ Usage::
 """
 
 import sys
-from typing import Any, Dict, Mapping, Sequence, Type, overload
+from typing import Any, Dict, Mapping, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
-from .literals import (
-    AuthTypeType,
-    ComputeTypeType,
-    EnvironmentTypeType,
-    FleetOverflowBehaviorType,
-    FleetSortByTypeType,
-    ImagePullCredentialsTypeType,
-    ProjectSortByTypeType,
-    ProjectVisibilityTypeType,
-    ReportCodeCoverageSortByTypeType,
-    ReportGroupSortByTypeType,
-    ReportGroupTrendFieldTypeType,
-    ReportTypeType,
-    RetryBuildBatchTypeType,
-    ServerTypeType,
-    SharedResourceSortByTypeType,
-    SortOrderTypeType,
-    SourceTypeType,
-    WebhookBuildTypeType,
-)
 from .paginator import (
     DescribeCodeCoveragesPaginator,
     DescribeTestCasesPaginator,
@@ -54,77 +34,104 @@ from .paginator import (
     ListSharedReportGroupsPaginator,
 )
 from .type_defs import (
+    BatchDeleteBuildsInputRequestTypeDef,
     BatchDeleteBuildsOutputTypeDef,
+    BatchGetBuildBatchesInputRequestTypeDef,
     BatchGetBuildBatchesOutputTypeDef,
+    BatchGetBuildsInputRequestTypeDef,
     BatchGetBuildsOutputTypeDef,
+    BatchGetFleetsInputRequestTypeDef,
     BatchGetFleetsOutputTypeDef,
+    BatchGetProjectsInputRequestTypeDef,
     BatchGetProjectsOutputTypeDef,
+    BatchGetReportGroupsInputRequestTypeDef,
     BatchGetReportGroupsOutputTypeDef,
+    BatchGetReportsInputRequestTypeDef,
     BatchGetReportsOutputTypeDef,
-    BuildBatchFilterTypeDef,
-    BuildStatusConfigTypeDef,
+    CreateFleetInputRequestTypeDef,
     CreateFleetOutputTypeDef,
+    CreateProjectInputRequestTypeDef,
     CreateProjectOutputTypeDef,
+    CreateReportGroupInputRequestTypeDef,
     CreateReportGroupOutputTypeDef,
+    CreateWebhookInputRequestTypeDef,
     CreateWebhookOutputTypeDef,
+    DeleteBuildBatchInputRequestTypeDef,
     DeleteBuildBatchOutputTypeDef,
+    DeleteFleetInputRequestTypeDef,
+    DeleteProjectInputRequestTypeDef,
+    DeleteReportGroupInputRequestTypeDef,
+    DeleteReportInputRequestTypeDef,
+    DeleteResourcePolicyInputRequestTypeDef,
+    DeleteSourceCredentialsInputRequestTypeDef,
     DeleteSourceCredentialsOutputTypeDef,
+    DeleteWebhookInputRequestTypeDef,
+    DescribeCodeCoveragesInputRequestTypeDef,
     DescribeCodeCoveragesOutputTypeDef,
+    DescribeTestCasesInputRequestTypeDef,
     DescribeTestCasesOutputTypeDef,
-    EnvironmentVariableTypeDef,
+    GetReportGroupTrendInputRequestTypeDef,
     GetReportGroupTrendOutputTypeDef,
+    GetResourcePolicyInputRequestTypeDef,
     GetResourcePolicyOutputTypeDef,
-    GitSubmodulesConfigTypeDef,
+    ImportSourceCredentialsInputRequestTypeDef,
     ImportSourceCredentialsOutputTypeDef,
+    InvalidateProjectCacheInputRequestTypeDef,
+    ListBuildBatchesForProjectInputRequestTypeDef,
     ListBuildBatchesForProjectOutputTypeDef,
+    ListBuildBatchesInputRequestTypeDef,
     ListBuildBatchesOutputTypeDef,
+    ListBuildsForProjectInputRequestTypeDef,
     ListBuildsForProjectOutputTypeDef,
+    ListBuildsInputRequestTypeDef,
     ListBuildsOutputTypeDef,
     ListCuratedEnvironmentImagesOutputTypeDef,
+    ListFleetsInputRequestTypeDef,
     ListFleetsOutputTypeDef,
+    ListProjectsInputRequestTypeDef,
     ListProjectsOutputTypeDef,
+    ListReportGroupsInputRequestTypeDef,
     ListReportGroupsOutputTypeDef,
+    ListReportsForReportGroupInputRequestTypeDef,
     ListReportsForReportGroupOutputTypeDef,
+    ListReportsInputRequestTypeDef,
     ListReportsOutputTypeDef,
+    ListSharedProjectsInputRequestTypeDef,
     ListSharedProjectsOutputTypeDef,
+    ListSharedReportGroupsInputRequestTypeDef,
     ListSharedReportGroupsOutputTypeDef,
     ListSourceCredentialsOutputTypeDef,
-    LogsConfigTypeDef,
-    ProjectArtifactsTypeDef,
-    ProjectBuildBatchConfigUnionTypeDef,
-    ProjectCacheUnionTypeDef,
-    ProjectEnvironmentUnionTypeDef,
-    ProjectFileSystemLocationTypeDef,
-    ProjectFleetTypeDef,
-    ProjectSourceTypeDef,
-    ProjectSourceVersionTypeDef,
+    PutResourcePolicyInputRequestTypeDef,
     PutResourcePolicyOutputTypeDef,
-    RegistryCredentialTypeDef,
-    ReportExportConfigTypeDef,
-    ReportFilterTypeDef,
+    RetryBuildBatchInputRequestTypeDef,
     RetryBuildBatchOutputTypeDef,
+    RetryBuildInputRequestTypeDef,
     RetryBuildOutputTypeDef,
-    ScalingConfigurationInputTypeDef,
-    SourceAuthTypeDef,
+    StartBuildBatchInputRequestTypeDef,
     StartBuildBatchOutputTypeDef,
+    StartBuildInputRequestTypeDef,
     StartBuildOutputTypeDef,
+    StopBuildBatchInputRequestTypeDef,
     StopBuildBatchOutputTypeDef,
+    StopBuildInputRequestTypeDef,
     StopBuildOutputTypeDef,
-    TagTypeDef,
-    TestCaseFilterTypeDef,
+    UpdateFleetInputRequestTypeDef,
     UpdateFleetOutputTypeDef,
+    UpdateProjectInputRequestTypeDef,
     UpdateProjectOutputTypeDef,
+    UpdateProjectVisibilityInputRequestTypeDef,
     UpdateProjectVisibilityOutputTypeDef,
+    UpdateReportGroupInputRequestTypeDef,
     UpdateReportGroupOutputTypeDef,
+    UpdateWebhookInputRequestTypeDef,
     UpdateWebhookOutputTypeDef,
-    VpcConfigUnionTypeDef,
-    WebhookFilterTypeDef,
 )
 
 if sys.version_info >= (3, 12):
-    from typing import Literal
+    from typing import Literal, Unpack
 else:
-    from typing_extensions import Literal
+    from typing_extensions import Literal, Unpack
+
 
 __all__ = ("CodeBuildClient",)
 
@@ -163,7 +170,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#exceptions)
         """
 
-    def batch_delete_builds(self, *, ids: Sequence[str]) -> BatchDeleteBuildsOutputTypeDef:
+    def batch_delete_builds(
+        self, **kwargs: Unpack[BatchDeleteBuildsInputRequestTypeDef]
+    ) -> BatchDeleteBuildsOutputTypeDef:
         """
         Deletes one or more builds.
 
@@ -171,7 +180,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#batch_delete_builds)
         """
 
-    def batch_get_build_batches(self, *, ids: Sequence[str]) -> BatchGetBuildBatchesOutputTypeDef:
+    def batch_get_build_batches(
+        self, **kwargs: Unpack[BatchGetBuildBatchesInputRequestTypeDef]
+    ) -> BatchGetBuildBatchesOutputTypeDef:
         """
         Retrieves information about one or more batch builds.
 
@@ -179,7 +190,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#batch_get_build_batches)
         """
 
-    def batch_get_builds(self, *, ids: Sequence[str]) -> BatchGetBuildsOutputTypeDef:
+    def batch_get_builds(
+        self, **kwargs: Unpack[BatchGetBuildsInputRequestTypeDef]
+    ) -> BatchGetBuildsOutputTypeDef:
         """
         Gets information about one or more builds.
 
@@ -187,7 +200,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#batch_get_builds)
         """
 
-    def batch_get_fleets(self, *, names: Sequence[str]) -> BatchGetFleetsOutputTypeDef:
+    def batch_get_fleets(
+        self, **kwargs: Unpack[BatchGetFleetsInputRequestTypeDef]
+    ) -> BatchGetFleetsOutputTypeDef:
         """
         Gets information about one or more compute fleets.
 
@@ -195,7 +210,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#batch_get_fleets)
         """
 
-    def batch_get_projects(self, *, names: Sequence[str]) -> BatchGetProjectsOutputTypeDef:
+    def batch_get_projects(
+        self, **kwargs: Unpack[BatchGetProjectsInputRequestTypeDef]
+    ) -> BatchGetProjectsOutputTypeDef:
         """
         Gets information about one or more build projects.
 
@@ -204,7 +221,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def batch_get_report_groups(
-        self, *, reportGroupArns: Sequence[str]
+        self, **kwargs: Unpack[BatchGetReportGroupsInputRequestTypeDef]
     ) -> BatchGetReportGroupsOutputTypeDef:
         """
         Returns an array of report groups.
@@ -213,7 +230,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#batch_get_report_groups)
         """
 
-    def batch_get_reports(self, *, reportArns: Sequence[str]) -> BatchGetReportsOutputTypeDef:
+    def batch_get_reports(
+        self, **kwargs: Unpack[BatchGetReportsInputRequestTypeDef]
+    ) -> BatchGetReportsOutputTypeDef:
         """
         Returns an array of reports.
 
@@ -238,17 +257,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def create_fleet(
-        self,
-        *,
-        name: str,
-        baseCapacity: int,
-        environmentType: EnvironmentTypeType,
-        computeType: ComputeTypeType,
-        scalingConfiguration: ScalingConfigurationInputTypeDef = ...,
-        overflowBehavior: FleetOverflowBehaviorType = ...,
-        vpcConfig: VpcConfigUnionTypeDef = ...,
-        fleetServiceRole: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateFleetInputRequestTypeDef]
     ) -> CreateFleetOutputTypeDef:
         """
         Creates a compute fleet.
@@ -258,29 +267,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def create_project(
-        self,
-        *,
-        name: str,
-        source: ProjectSourceTypeDef,
-        artifacts: ProjectArtifactsTypeDef,
-        environment: ProjectEnvironmentUnionTypeDef,
-        serviceRole: str,
-        description: str = ...,
-        secondarySources: Sequence[ProjectSourceTypeDef] = ...,
-        sourceVersion: str = ...,
-        secondarySourceVersions: Sequence[ProjectSourceVersionTypeDef] = ...,
-        secondaryArtifacts: Sequence[ProjectArtifactsTypeDef] = ...,
-        cache: ProjectCacheUnionTypeDef = ...,
-        timeoutInMinutes: int = ...,
-        queuedTimeoutInMinutes: int = ...,
-        encryptionKey: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
-        vpcConfig: VpcConfigUnionTypeDef = ...,
-        badgeEnabled: bool = ...,
-        logsConfig: LogsConfigTypeDef = ...,
-        fileSystemLocations: Sequence[ProjectFileSystemLocationTypeDef] = ...,
-        buildBatchConfig: ProjectBuildBatchConfigUnionTypeDef = ...,
-        concurrentBuildLimit: int = ...,
+        self, **kwargs: Unpack[CreateProjectInputRequestTypeDef]
     ) -> CreateProjectOutputTypeDef:
         """
         Creates a build project.
@@ -290,12 +277,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def create_report_group(
-        self,
-        *,
-        name: str,
-        type: ReportTypeType,
-        exportConfig: ReportExportConfigTypeDef,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[CreateReportGroupInputRequestTypeDef]
     ) -> CreateReportGroupOutputTypeDef:
         """
         Creates a report group.
@@ -305,13 +287,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def create_webhook(
-        self,
-        *,
-        projectName: str,
-        branchFilter: str = ...,
-        filterGroups: Sequence[Sequence[WebhookFilterTypeDef]] = ...,
-        buildType: WebhookBuildTypeType = ...,
-        manualCreation: bool = ...,
+        self, **kwargs: Unpack[CreateWebhookInputRequestTypeDef]
     ) -> CreateWebhookOutputTypeDef:
         """
         For an existing CodeBuild build project that has its source code stored in a
@@ -323,7 +299,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#create_webhook)
         """
 
-    def delete_build_batch(self, *, id: str) -> DeleteBuildBatchOutputTypeDef:
+    def delete_build_batch(
+        self, **kwargs: Unpack[DeleteBuildBatchInputRequestTypeDef]
+    ) -> DeleteBuildBatchOutputTypeDef:
         """
         Deletes a batch build.
 
@@ -331,7 +309,7 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_build_batch)
         """
 
-    def delete_fleet(self, *, arn: str) -> Dict[str, Any]:
+    def delete_fleet(self, **kwargs: Unpack[DeleteFleetInputRequestTypeDef]) -> Dict[str, Any]:
         """
         Deletes a compute fleet.
 
@@ -339,7 +317,7 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_fleet)
         """
 
-    def delete_project(self, *, name: str) -> Dict[str, Any]:
+    def delete_project(self, **kwargs: Unpack[DeleteProjectInputRequestTypeDef]) -> Dict[str, Any]:
         """
         Deletes a build project.
 
@@ -347,7 +325,7 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_project)
         """
 
-    def delete_report(self, *, arn: str) -> Dict[str, Any]:
+    def delete_report(self, **kwargs: Unpack[DeleteReportInputRequestTypeDef]) -> Dict[str, Any]:
         """
         Deletes a report.
 
@@ -355,7 +333,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_report)
         """
 
-    def delete_report_group(self, *, arn: str, deleteReports: bool = ...) -> Dict[str, Any]:
+    def delete_report_group(
+        self, **kwargs: Unpack[DeleteReportGroupInputRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes a report group.
 
@@ -363,7 +343,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_report_group)
         """
 
-    def delete_resource_policy(self, *, resourceArn: str) -> Dict[str, Any]:
+    def delete_resource_policy(
+        self, **kwargs: Unpack[DeleteResourcePolicyInputRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Deletes a resource policy that is identified by its resource ARN.
 
@@ -371,7 +353,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_resource_policy)
         """
 
-    def delete_source_credentials(self, *, arn: str) -> DeleteSourceCredentialsOutputTypeDef:
+    def delete_source_credentials(
+        self, **kwargs: Unpack[DeleteSourceCredentialsInputRequestTypeDef]
+    ) -> DeleteSourceCredentialsOutputTypeDef:
         """
         Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials.
 
@@ -379,7 +363,7 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_source_credentials)
         """
 
-    def delete_webhook(self, *, projectName: str) -> Dict[str, Any]:
+    def delete_webhook(self, **kwargs: Unpack[DeleteWebhookInputRequestTypeDef]) -> Dict[str, Any]:
         """
         For an existing CodeBuild build project that has its source code stored in a
         GitHub or Bitbucket repository, stops CodeBuild from rebuilding the source code
@@ -391,15 +375,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def describe_code_coverages(
-        self,
-        *,
-        reportArn: str,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        sortOrder: SortOrderTypeType = ...,
-        sortBy: ReportCodeCoverageSortByTypeType = ...,
-        minLineCoveragePercentage: float = ...,
-        maxLineCoveragePercentage: float = ...,
+        self, **kwargs: Unpack[DescribeCodeCoveragesInputRequestTypeDef]
     ) -> DescribeCodeCoveragesOutputTypeDef:
         """
         Retrieves one or more code coverage reports.
@@ -409,12 +385,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def describe_test_cases(
-        self,
-        *,
-        reportArn: str,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filter: TestCaseFilterTypeDef = ...,
+        self, **kwargs: Unpack[DescribeTestCasesInputRequestTypeDef]
     ) -> DescribeTestCasesOutputTypeDef:
         """
         Returns a list of details about test cases for a report.
@@ -438,11 +409,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def get_report_group_trend(
-        self,
-        *,
-        reportGroupArn: str,
-        trendField: ReportGroupTrendFieldTypeType,
-        numOfReports: int = ...,
+        self, **kwargs: Unpack[GetReportGroupTrendInputRequestTypeDef]
     ) -> GetReportGroupTrendOutputTypeDef:
         """
         Analyzes and accumulates test report values for the specified test reports.
@@ -451,7 +418,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#get_report_group_trend)
         """
 
-    def get_resource_policy(self, *, resourceArn: str) -> GetResourcePolicyOutputTypeDef:
+    def get_resource_policy(
+        self, **kwargs: Unpack[GetResourcePolicyInputRequestTypeDef]
+    ) -> GetResourcePolicyOutputTypeDef:
         """
         Gets a resource policy that is identified by its resource ARN.
 
@@ -460,24 +429,21 @@ class CodeBuildClient(BaseClient):
         """
 
     def import_source_credentials(
-        self,
-        *,
-        token: str,
-        serverType: ServerTypeType,
-        authType: AuthTypeType,
-        username: str = ...,
-        shouldOverwrite: bool = ...,
+        self, **kwargs: Unpack[ImportSourceCredentialsInputRequestTypeDef]
     ) -> ImportSourceCredentialsOutputTypeDef:
         """
         Imports the source repository credentials for an CodeBuild project that has its
-        source code stored in a GitHub, GitHub Enterprise, or Bitbucket
+        source code stored in a GitHub, GitHub Enterprise, GitLab, GitLab Self Managed,
+        or Bitbucket
         repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#import_source_credentials)
         """
 
-    def invalidate_project_cache(self, *, projectName: str) -> Dict[str, Any]:
+    def invalidate_project_cache(
+        self, **kwargs: Unpack[InvalidateProjectCacheInputRequestTypeDef]
+    ) -> Dict[str, Any]:
         """
         Resets the cache for a project.
 
@@ -486,12 +452,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_build_batches(
-        self,
-        *,
-        filter: BuildBatchFilterTypeDef = ...,
-        maxResults: int = ...,
-        sortOrder: SortOrderTypeType = ...,
-        nextToken: str = ...,
+        self, **kwargs: Unpack[ListBuildBatchesInputRequestTypeDef]
     ) -> ListBuildBatchesOutputTypeDef:
         """
         Retrieves the identifiers of your build batches in the current region.
@@ -501,13 +462,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_build_batches_for_project(
-        self,
-        *,
-        projectName: str = ...,
-        filter: BuildBatchFilterTypeDef = ...,
-        maxResults: int = ...,
-        sortOrder: SortOrderTypeType = ...,
-        nextToken: str = ...,
+        self, **kwargs: Unpack[ListBuildBatchesForProjectInputRequestTypeDef]
     ) -> ListBuildBatchesForProjectOutputTypeDef:
         """
         Retrieves the identifiers of the build batches for a specific project.
@@ -517,7 +472,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_builds(
-        self, *, sortOrder: SortOrderTypeType = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListBuildsInputRequestTypeDef]
     ) -> ListBuildsOutputTypeDef:
         """
         Gets a list of build IDs, with each build ID representing a single build.
@@ -527,7 +482,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_builds_for_project(
-        self, *, projectName: str, sortOrder: SortOrderTypeType = ..., nextToken: str = ...
+        self, **kwargs: Unpack[ListBuildsForProjectInputRequestTypeDef]
     ) -> ListBuildsForProjectOutputTypeDef:
         """
         Gets a list of build identifiers for the specified build project, with each
@@ -547,12 +502,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_fleets(
-        self,
-        *,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        sortOrder: SortOrderTypeType = ...,
-        sortBy: FleetSortByTypeType = ...,
+        self, **kwargs: Unpack[ListFleetsInputRequestTypeDef]
     ) -> ListFleetsOutputTypeDef:
         """
         Gets a list of compute fleet names with each compute fleet name representing a
@@ -564,11 +514,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_projects(
-        self,
-        *,
-        sortBy: ProjectSortByTypeType = ...,
-        sortOrder: SortOrderTypeType = ...,
-        nextToken: str = ...,
+        self, **kwargs: Unpack[ListProjectsInputRequestTypeDef]
     ) -> ListProjectsOutputTypeDef:
         """
         Gets a list of build project names, with each build project name representing a
@@ -580,12 +526,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_report_groups(
-        self,
-        *,
-        sortOrder: SortOrderTypeType = ...,
-        sortBy: ReportGroupSortByTypeType = ...,
-        nextToken: str = ...,
-        maxResults: int = ...,
+        self, **kwargs: Unpack[ListReportGroupsInputRequestTypeDef]
     ) -> ListReportGroupsOutputTypeDef:
         """
         Gets a list ARNs for the report groups in the current Amazon Web Services
@@ -596,12 +537,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_reports(
-        self,
-        *,
-        sortOrder: SortOrderTypeType = ...,
-        nextToken: str = ...,
-        maxResults: int = ...,
-        filter: ReportFilterTypeDef = ...,
+        self, **kwargs: Unpack[ListReportsInputRequestTypeDef]
     ) -> ListReportsOutputTypeDef:
         """
         Returns a list of ARNs for the reports in the current Amazon Web Services
@@ -612,13 +548,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_reports_for_report_group(
-        self,
-        *,
-        reportGroupArn: str,
-        nextToken: str = ...,
-        sortOrder: SortOrderTypeType = ...,
-        maxResults: int = ...,
-        filter: ReportFilterTypeDef = ...,
+        self, **kwargs: Unpack[ListReportsForReportGroupInputRequestTypeDef]
     ) -> ListReportsForReportGroupOutputTypeDef:
         """
         Returns a list of ARNs for the reports that belong to a `ReportGroup`.
@@ -628,12 +558,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_shared_projects(
-        self,
-        *,
-        sortBy: SharedResourceSortByTypeType = ...,
-        sortOrder: SortOrderTypeType = ...,
-        maxResults: int = ...,
-        nextToken: str = ...,
+        self, **kwargs: Unpack[ListSharedProjectsInputRequestTypeDef]
     ) -> ListSharedProjectsOutputTypeDef:
         """
         Gets a list of projects that are shared with other Amazon Web Services accounts
@@ -645,12 +570,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def list_shared_report_groups(
-        self,
-        *,
-        sortOrder: SortOrderTypeType = ...,
-        sortBy: SharedResourceSortByTypeType = ...,
-        nextToken: str = ...,
-        maxResults: int = ...,
+        self, **kwargs: Unpack[ListSharedReportGroupsInputRequestTypeDef]
     ) -> ListSharedReportGroupsOutputTypeDef:
         """
         Gets a list of report groups that are shared with other Amazon Web Services
@@ -670,7 +590,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def put_resource_policy(
-        self, *, policy: str, resourceArn: str
+        self, **kwargs: Unpack[PutResourcePolicyInputRequestTypeDef]
     ) -> PutResourcePolicyOutputTypeDef:
         """
         Stores a resource policy for the ARN of a `Project` or `ReportGroup` object.
@@ -679,7 +599,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#put_resource_policy)
         """
 
-    def retry_build(self, *, id: str = ..., idempotencyToken: str = ...) -> RetryBuildOutputTypeDef:
+    def retry_build(
+        self, **kwargs: Unpack[RetryBuildInputRequestTypeDef]
+    ) -> RetryBuildOutputTypeDef:
         """
         Restarts a build.
 
@@ -688,11 +610,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def retry_build_batch(
-        self,
-        *,
-        id: str = ...,
-        idempotencyToken: str = ...,
-        retryType: RetryBuildBatchTypeType = ...,
+        self, **kwargs: Unpack[RetryBuildBatchInputRequestTypeDef]
     ) -> RetryBuildBatchOutputTypeDef:
         """
         Restarts a failed batch build.
@@ -702,40 +620,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def start_build(
-        self,
-        *,
-        projectName: str,
-        secondarySourcesOverride: Sequence[ProjectSourceTypeDef] = ...,
-        secondarySourcesVersionOverride: Sequence[ProjectSourceVersionTypeDef] = ...,
-        sourceVersion: str = ...,
-        artifactsOverride: ProjectArtifactsTypeDef = ...,
-        secondaryArtifactsOverride: Sequence[ProjectArtifactsTypeDef] = ...,
-        environmentVariablesOverride: Sequence[EnvironmentVariableTypeDef] = ...,
-        sourceTypeOverride: SourceTypeType = ...,
-        sourceLocationOverride: str = ...,
-        sourceAuthOverride: SourceAuthTypeDef = ...,
-        gitCloneDepthOverride: int = ...,
-        gitSubmodulesConfigOverride: GitSubmodulesConfigTypeDef = ...,
-        buildspecOverride: str = ...,
-        insecureSslOverride: bool = ...,
-        reportBuildStatusOverride: bool = ...,
-        buildStatusConfigOverride: BuildStatusConfigTypeDef = ...,
-        environmentTypeOverride: EnvironmentTypeType = ...,
-        imageOverride: str = ...,
-        computeTypeOverride: ComputeTypeType = ...,
-        certificateOverride: str = ...,
-        cacheOverride: ProjectCacheUnionTypeDef = ...,
-        serviceRoleOverride: str = ...,
-        privilegedModeOverride: bool = ...,
-        timeoutInMinutesOverride: int = ...,
-        queuedTimeoutInMinutesOverride: int = ...,
-        encryptionKeyOverride: str = ...,
-        idempotencyToken: str = ...,
-        logsConfigOverride: LogsConfigTypeDef = ...,
-        registryCredentialOverride: RegistryCredentialTypeDef = ...,
-        imagePullCredentialsTypeOverride: ImagePullCredentialsTypeType = ...,
-        debugSessionEnabled: bool = ...,
-        fleetOverride: ProjectFleetTypeDef = ...,
+        self, **kwargs: Unpack[StartBuildInputRequestTypeDef]
     ) -> StartBuildOutputTypeDef:
         """
         Starts running a build with the settings defined in the project.
@@ -745,39 +630,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def start_build_batch(
-        self,
-        *,
-        projectName: str,
-        secondarySourcesOverride: Sequence[ProjectSourceTypeDef] = ...,
-        secondarySourcesVersionOverride: Sequence[ProjectSourceVersionTypeDef] = ...,
-        sourceVersion: str = ...,
-        artifactsOverride: ProjectArtifactsTypeDef = ...,
-        secondaryArtifactsOverride: Sequence[ProjectArtifactsTypeDef] = ...,
-        environmentVariablesOverride: Sequence[EnvironmentVariableTypeDef] = ...,
-        sourceTypeOverride: SourceTypeType = ...,
-        sourceLocationOverride: str = ...,
-        sourceAuthOverride: SourceAuthTypeDef = ...,
-        gitCloneDepthOverride: int = ...,
-        gitSubmodulesConfigOverride: GitSubmodulesConfigTypeDef = ...,
-        buildspecOverride: str = ...,
-        insecureSslOverride: bool = ...,
-        reportBuildBatchStatusOverride: bool = ...,
-        environmentTypeOverride: EnvironmentTypeType = ...,
-        imageOverride: str = ...,
-        computeTypeOverride: ComputeTypeType = ...,
-        certificateOverride: str = ...,
-        cacheOverride: ProjectCacheUnionTypeDef = ...,
-        serviceRoleOverride: str = ...,
-        privilegedModeOverride: bool = ...,
-        buildTimeoutInMinutesOverride: int = ...,
-        queuedTimeoutInMinutesOverride: int = ...,
-        encryptionKeyOverride: str = ...,
-        idempotencyToken: str = ...,
-        logsConfigOverride: LogsConfigTypeDef = ...,
-        registryCredentialOverride: RegistryCredentialTypeDef = ...,
-        imagePullCredentialsTypeOverride: ImagePullCredentialsTypeType = ...,
-        buildBatchConfigOverride: ProjectBuildBatchConfigUnionTypeDef = ...,
-        debugSessionEnabled: bool = ...,
+        self, **kwargs: Unpack[StartBuildBatchInputRequestTypeDef]
     ) -> StartBuildBatchOutputTypeDef:
         """
         Starts a batch build for a project.
@@ -786,7 +639,7 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#start_build_batch)
         """
 
-    def stop_build(self, *, id: str) -> StopBuildOutputTypeDef:
+    def stop_build(self, **kwargs: Unpack[StopBuildInputRequestTypeDef]) -> StopBuildOutputTypeDef:
         """
         Attempts to stop running a build.
 
@@ -794,7 +647,9 @@ class CodeBuildClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#stop_build)
         """
 
-    def stop_build_batch(self, *, id: str) -> StopBuildBatchOutputTypeDef:
+    def stop_build_batch(
+        self, **kwargs: Unpack[StopBuildBatchInputRequestTypeDef]
+    ) -> StopBuildBatchOutputTypeDef:
         """
         Stops a running batch build.
 
@@ -803,17 +658,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def update_fleet(
-        self,
-        *,
-        arn: str,
-        baseCapacity: int = ...,
-        environmentType: EnvironmentTypeType = ...,
-        computeType: ComputeTypeType = ...,
-        scalingConfiguration: ScalingConfigurationInputTypeDef = ...,
-        overflowBehavior: FleetOverflowBehaviorType = ...,
-        vpcConfig: VpcConfigUnionTypeDef = ...,
-        fleetServiceRole: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[UpdateFleetInputRequestTypeDef]
     ) -> UpdateFleetOutputTypeDef:
         """
         Updates a compute fleet.
@@ -823,29 +668,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def update_project(
-        self,
-        *,
-        name: str,
-        description: str = ...,
-        source: ProjectSourceTypeDef = ...,
-        secondarySources: Sequence[ProjectSourceTypeDef] = ...,
-        sourceVersion: str = ...,
-        secondarySourceVersions: Sequence[ProjectSourceVersionTypeDef] = ...,
-        artifacts: ProjectArtifactsTypeDef = ...,
-        secondaryArtifacts: Sequence[ProjectArtifactsTypeDef] = ...,
-        cache: ProjectCacheUnionTypeDef = ...,
-        environment: ProjectEnvironmentUnionTypeDef = ...,
-        serviceRole: str = ...,
-        timeoutInMinutes: int = ...,
-        queuedTimeoutInMinutes: int = ...,
-        encryptionKey: str = ...,
-        tags: Sequence[TagTypeDef] = ...,
-        vpcConfig: VpcConfigUnionTypeDef = ...,
-        badgeEnabled: bool = ...,
-        logsConfig: LogsConfigTypeDef = ...,
-        fileSystemLocations: Sequence[ProjectFileSystemLocationTypeDef] = ...,
-        buildBatchConfig: ProjectBuildBatchConfigUnionTypeDef = ...,
-        concurrentBuildLimit: int = ...,
+        self, **kwargs: Unpack[UpdateProjectInputRequestTypeDef]
     ) -> UpdateProjectOutputTypeDef:
         """
         Changes the settings of a build project.
@@ -855,11 +678,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def update_project_visibility(
-        self,
-        *,
-        projectArn: str,
-        projectVisibility: ProjectVisibilityTypeType,
-        resourceAccessRole: str = ...,
+        self, **kwargs: Unpack[UpdateProjectVisibilityInputRequestTypeDef]
     ) -> UpdateProjectVisibilityOutputTypeDef:
         """
         Changes the public visibility for a project.
@@ -869,11 +688,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def update_report_group(
-        self,
-        *,
-        arn: str,
-        exportConfig: ReportExportConfigTypeDef = ...,
-        tags: Sequence[TagTypeDef] = ...,
+        self, **kwargs: Unpack[UpdateReportGroupInputRequestTypeDef]
     ) -> UpdateReportGroupOutputTypeDef:
         """
         Updates a report group.
@@ -883,13 +698,7 @@ class CodeBuildClient(BaseClient):
         """
 
     def update_webhook(
-        self,
-        *,
-        projectName: str,
-        branchFilter: str = ...,
-        rotateSecret: bool = ...,
-        filterGroups: Sequence[Sequence[WebhookFilterTypeDef]] = ...,
-        buildType: WebhookBuildTypeType = ...,
+        self, **kwargs: Unpack[UpdateWebhookInputRequestTypeDef]
     ) -> UpdateWebhookOutputTypeDef:
         """
         Updates the webhook associated with an CodeBuild build project.
