@@ -14,7 +14,7 @@ Usage::
 
 import sys
 from datetime import datetime
-from typing import Dict, List, Sequence, Union
+from typing import Dict, List, Sequence
 
 from .literals import (
     ArtifactNamespaceType,
@@ -57,20 +57,14 @@ from .literals import (
     StatusTypeType,
     WebhookBuildTypeType,
     WebhookFilterTypeType,
+    WebhookScopeTypeType,
 )
 
 if sys.version_info >= (3, 12):
-    from typing import Literal
+    from typing import Literal, NotRequired, TypedDict
 else:
-    from typing_extensions import Literal
-if sys.version_info >= (3, 12):
-    from typing import NotRequired
-else:
-    from typing_extensions import NotRequired
-if sys.version_info >= (3, 12):
-    from typing import TypedDict
-else:
-    from typing_extensions import TypedDict
+    from typing_extensions import Literal, NotRequired, TypedDict
+
 
 __all__ = (
     "BatchDeleteBuildsInputRequestTypeDef",
@@ -103,6 +97,7 @@ __all__ = (
     "VpcConfigTypeDef",
     "ProjectArtifactsTypeDef",
     "ProjectCacheTypeDef",
+    "ScopeConfigurationTypeDef",
     "WebhookFilterTypeDef",
     "DeleteBuildBatchInputRequestTypeDef",
     "DeleteFleetInputRequestTypeDef",
@@ -175,8 +170,6 @@ __all__ = (
     "BuildPhaseTypeDef",
     "BuildSummaryTypeDef",
     "DescribeCodeCoveragesOutputTypeDef",
-    "VpcConfigUnionTypeDef",
-    "ProjectCacheUnionTypeDef",
     "CreateWebhookInputRequestTypeDef",
     "UpdateWebhookInputRequestTypeDef",
     "WebhookTypeDef",
@@ -207,12 +200,10 @@ __all__ = (
     "ReportExportConfigTypeDef",
     "ScalingConfigurationInputTypeDef",
     "ScalingConfigurationOutputTypeDef",
-    "ProjectBuildBatchConfigUnionTypeDef",
     "BuildGroupTypeDef",
     "CreateWebhookOutputTypeDef",
     "UpdateWebhookOutputTypeDef",
     "EnvironmentPlatformTypeDef",
-    "ProjectEnvironmentUnionTypeDef",
     "BuildTypeDef",
     "CreateProjectInputRequestTypeDef",
     "ProjectTypeDef",
@@ -487,6 +478,14 @@ ProjectCacheTypeDef = TypedDict(
         "modes": NotRequired[Sequence[CacheModeType]],
     },
 )
+ScopeConfigurationTypeDef = TypedDict(
+    "ScopeConfigurationTypeDef",
+    {
+        "name": str,
+        "scope": WebhookScopeTypeType,
+        "domain": NotRequired[str],
+    },
+)
 WebhookFilterTypeDef = TypedDict(
     "WebhookFilterTypeDef",
     {
@@ -1058,8 +1057,6 @@ DescribeCodeCoveragesOutputTypeDef = TypedDict(
         "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
-VpcConfigUnionTypeDef = Union[VpcConfigTypeDef, VpcConfigOutputTypeDef]
-ProjectCacheUnionTypeDef = Union[ProjectCacheTypeDef, ProjectCacheOutputTypeDef]
 CreateWebhookInputRequestTypeDef = TypedDict(
     "CreateWebhookInputRequestTypeDef",
     {
@@ -1068,6 +1065,7 @@ CreateWebhookInputRequestTypeDef = TypedDict(
         "filterGroups": NotRequired[Sequence[Sequence[WebhookFilterTypeDef]]],
         "buildType": NotRequired[WebhookBuildTypeType],
         "manualCreation": NotRequired[bool],
+        "scopeConfiguration": NotRequired[ScopeConfigurationTypeDef],
     },
 )
 UpdateWebhookInputRequestTypeDef = TypedDict(
@@ -1091,6 +1089,7 @@ WebhookTypeDef = TypedDict(
         "buildType": NotRequired[WebhookBuildTypeType],
         "manualCreation": NotRequired[bool],
         "lastModifiedSecret": NotRequired[datetime],
+        "scopeConfiguration": NotRequired[ScopeConfigurationTypeDef],
     },
 )
 DescribeCodeCoveragesInputDescribeCodeCoveragesPaginateTypeDef = TypedDict(
@@ -1342,9 +1341,6 @@ ScalingConfigurationOutputTypeDef = TypedDict(
         "desiredCapacity": NotRequired[int],
     },
 )
-ProjectBuildBatchConfigUnionTypeDef = Union[
-    ProjectBuildBatchConfigTypeDef, ProjectBuildBatchConfigOutputTypeDef
-]
 BuildGroupTypeDef = TypedDict(
     "BuildGroupTypeDef",
     {
@@ -1376,7 +1372,6 @@ EnvironmentPlatformTypeDef = TypedDict(
         "languages": NotRequired[List[EnvironmentLanguageTypeDef]],
     },
 )
-ProjectEnvironmentUnionTypeDef = Union[ProjectEnvironmentTypeDef, ProjectEnvironmentOutputTypeDef]
 BuildTypeDef = TypedDict(
     "BuildTypeDef",
     {
@@ -1629,6 +1624,7 @@ CreateFleetInputRequestTypeDef = TypedDict(
         "scalingConfiguration": NotRequired[ScalingConfigurationInputTypeDef],
         "overflowBehavior": NotRequired[FleetOverflowBehaviorType],
         "vpcConfig": NotRequired[VpcConfigTypeDef],
+        "imageId": NotRequired[str],
         "fleetServiceRole": NotRequired[str],
         "tags": NotRequired[Sequence[TagTypeDef]],
     },
@@ -1643,6 +1639,7 @@ UpdateFleetInputRequestTypeDef = TypedDict(
         "scalingConfiguration": NotRequired[ScalingConfigurationInputTypeDef],
         "overflowBehavior": NotRequired[FleetOverflowBehaviorType],
         "vpcConfig": NotRequired[VpcConfigTypeDef],
+        "imageId": NotRequired[str],
         "fleetServiceRole": NotRequired[str],
         "tags": NotRequired[Sequence[TagTypeDef]],
     },
@@ -1662,6 +1659,7 @@ FleetTypeDef = TypedDict(
         "scalingConfiguration": NotRequired[ScalingConfigurationOutputTypeDef],
         "overflowBehavior": NotRequired[FleetOverflowBehaviorType],
         "vpcConfig": NotRequired[VpcConfigOutputTypeDef],
+        "imageId": NotRequired[str],
         "fleetServiceRole": NotRequired[str],
         "tags": NotRequired[List[TagTypeDef]],
     },
